package com.tappli.android.asynctasksample;

import java.util.Date;

import android.os.AsyncTask;

/**
 * サンプル AsyncTask<T1, T2, T3> T1 ... 実行時に渡すクラス T2 ... 途中経過を伝えるクラス(今回未使用) T3 ...
 * 処理結果を伝えるクラス
 * 
 * @author t2low
 * 
 */
public class SampleTask extends AsyncTask<Long, Integer, Date> {

	private SampleListener listener = null;

	/**
	 * コンストラクタで処理完了時のリスナーを渡しておく
	 * 
	 * @param listener
	 */
	public SampleTask(SampleListener listener) {
		this.listener = listener;
	}

	@Override
	protected Date doInBackground(Long... params) {
		// ここはGUIとは別のスレッド
		// この中からUIをさわってはダメ

		// バックグラウンドで行う処理を書く

		long start = System.currentTimeMillis();
		long end = start + params[0];

		while (end > System.currentTimeMillis()) {
			// 重い処理の代わり
			// params[0]で指定された秒数待つだけ

			// 途中経過を伝える場合は以下のメソッドを使う
			// int progress = 0;
			// publishProgress(Integer.valueOf(progress));
		}

		return new Date();
	}

	@Override
	protected void onProgressUpdate(Integer... values) {
		// ここはGUIと同じスレッド

		// publishProgress()で詰められたクラスはここに通知される
	}

	@Override
	protected void onPostExecute(Date result) {
		// ここはGUIと同じスレッド

		// 処理完了時に呼ばれるメソッド
		// doInBackground()の戻り値がここに通知される

		if (listener != null) {
			listener.onFinish(result);
		}
	}

	/**
	 * 結果通知用のリスナーを用意してみたり。
	 * 
	 * @author t2low
	 * 
	 */
	public interface SampleListener {
		public void onFinish(Date result);
	}
}
